@@ -1,13 +1,11 @@
 package Parse::ErrorString::Perl;
-BEGIN {
-  $Parse::ErrorString::Perl::VERSION = '0.15';
-}
-
-# ABSTRACT: Parse error messages from the perl interpreter
 
+use v5.8.7;
 use strict;
 use warnings;
 
+our $VERSION = '0.21';
+
 use Carp qw(carp cluck);
 use Pod::Find ();
 use Pod::POM 0.27 ();
@@ -127,10 +125,10 @@ sub _prepare_diagnostics {
 				}
 			}
 			my $lhs = join( '', @toks );
-			$transfmt{$header}{pat} = "    s{^$lhs}\n     {\Q$header\E}s\n\t&& return 1;\n";
+			$transfmt{$header}{pat} = "    s<^$lhs>\n     <\Q$header\E>s\n\t&& return 1;\n";
 			$transfmt{$header}{len} = $conlen;
 		} else {
-			$transfmt{$header}{pat} = "    m{^\Q$header\E} && return 1;\n";
+			$transfmt{$header}{pat} = "    m<^\Q$header\E> && return 1;\n";
 			$transfmt{$header}{len} = length($header);
 		}
 	}
@@ -426,18 +424,12 @@ sub _prepare_localized_diagnostics {
 
 1;
 
-
-
-=pod
+__END__
 
 =head1 NAME
 
 Parse::ErrorString::Perl - Parse error messages from the perl interpreter
 
-=head1 VERSION
-
-version 0.15
-
 =head1 SYNOPSIS
 
     use Parse::ErrorString::Perl;
@@ -454,6 +446,7 @@ version 0.15
         ' on line ' . $error->line . "\n";
     }
 
+
 =head1 METHODS
 
 =over
@@ -494,53 +487,41 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Parse::ErrorString::Perl
 
-=over 4
+=head1 AUTHOR
 
-=item * RT: CPAN's request tracker
+Petar Shangov, <pshangov at yahoo.com>
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Parse-ErrorString-Perl>
+=head1 COPYRIGHT
 
-=item * AnnoCPAN: Annotated CPAN documentation
+Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+L<http://padre.perlide.org/>
 
-L<http://annocpan.org/dist/Parse-ErrorString-Perl>
+=head1 LICENSE
 
-=item * CPAN Ratings
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl 5 itself.
 
-L<http://cpanratings.perl.org/d/Parse-ErrorString-Perl>
+=head1 DISCLAIMER OF WARRANTY
 
-=item * Search CPAN
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
 
-L<http://search.cpan.org/dist/Parse-ErrorString-Perl/>
-
-=back
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Petar Shangov, C<< <pshangov at yahoo.com> >>
-
-=item *
-
-Gabor Szabo L<http://szabgab.com/>
-
-=item *
-
-Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Petar Shangov.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =cut
-
-
-__END__
-
