@@ -1,13 +1,11 @@
 package Parse::ErrorString::Perl::StackItem;
-BEGIN {
-  $Parse::ErrorString::Perl::StackItem::VERSION = '0.15';
-}
 
-#ABSTRACT: a Perl stack item object
 
 use strict;
 use warnings;
 
+our $VERSION = '0.21';
+
 sub new {
 	my ( $class, $self ) = @_;
 	bless $self, ref $class || $class;
@@ -24,19 +22,13 @@ use Class::XSAccessor getters => {
 
 1;
 
-
-
-=pod
+__END__
 
 =head1 NAME
 
 Parse::ErrorString::Perl::StackItem - a Perl stack item object
 
-=head1 VERSION
-
-version 0.15
-
-=head1 Parse::ErrorString::Perl::StackItem
+=head1 DESCRIPTION
 
 =over
 
@@ -64,33 +56,8 @@ The line where the subroutine was called.
 
 =back
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Petar Shangov, C<< <pshangov at yahoo.com> >>
-
-=item *
-
-Gabor Szabo L<http://szabgab.com/>
-
-=item *
-
-Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Petar Shangov.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
-
-__END__
+# Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+# LICENSE
+# This program is free software; you can redistribute it and/or
+# modify it under the same terms as Perl 5 itself.
 
